@@ -10,7 +10,8 @@ f.exp <- function(x,xi,alfa) {
   #   stop("x must be higher or equal than xi")
   # } 
 
-  f <- alfa^(-1) * exp(-(x - xi)/alfa)
+  #f <- alfa^(-1) * exp(-(x - xi)/alfa)
+  f <- dexp(x - xi, rate=1/alfa)
 
   return(f)
 
@@ -22,7 +23,8 @@ F.exp <- function(x,xi,alfa) {
   #   stop("x must be higher or equal than xi")
   # } 
 
-  F <- 1 - exp(-(x - xi)/alfa)
+  #F <- 1 - exp(-(x - xi)/alfa)
+  F <- pexp(x - xi, rate=1/alfa)
 
   return(F)
 
@@ -34,7 +36,8 @@ invF.exp <- function(F,xi,alfa) {
   #   stop("F must be between 0 and 1")
   # } 
 
-  x <- xi - alfa*log(1 - F)
+  #x <- xi - alfa*log(1 - F)
+  x <- xi + qexp(F, rate=1/alfa)
 
   return(x)
 
@@ -66,8 +69,9 @@ par.exp <- function(lambda1,lambda2) {
 
 rand.exp <- function(numerosita,xi,alfa) {
 
-  F <- runif(numerosita, min=0.0000000001, max=0.9999999999)
-  x <- invF.exp(F,xi,alfa)
+  #F <- runif(numerosita, min=0.0000000001, max=0.9999999999)
+  #x <- invF.exp(F,xi,alfa)
+  x <- xi + rexp(numerosita, rate=1/alfa)
 
   return(x)
 }
